/*
 * Copyright 1993-2009 NVIDIA Corporation.  All rights reserved.
 *
 * NVIDIA Corporation and its licensors retain all intellectual property and 
 * proprietary rights in and to this software and related documentation. 
 * Any use, reproduction, disclosure, or distribution of this software 
 * and related documentation without an express license agreement from
 * NVIDIA Corporation is strictly prohibited.
 *
 * Please refer to the applicable NVIDIA end user license agreement (EULA) 
 * associated with this source code for terms and conditions that govern 
 * your use of this NVIDIA software.
 * 
 */

#include <vector_types.h>
#include <math.h>
#include <algorithm>

////////////////////////////////////////////////////////////////////////////////
// export C interface
extern "C" 
void computeGold( float d, float* reference, int imageW, int imageH, float4* fd);

void
computeGold( float d, float* reference, int imageW, int imageH, float4* fd) 
{
    for( unsigned int i = 0; i < imageW; ++i) 
    {
        const   int ix = i;
    	const   int iy = 0;

	if ((ix<imageW) && (iy<imageH))
	{
		float b = (ix+0.5f)/imageW;
		float c = (iy+0.5f)/imageH;
		float a = 1.0f-b-c;

    		float4 ftmp;

		ftmp.z = a*fd[0].z+b*fd[1].z+c*fd[2].z+d*fd[3].z;
		ftmp.w = a*fd[0].w+b*fd[1].w+c*fd[2].w+d*fd[3].w;

		ftmp.z/=ftmp.w;

		reference[i] 	= std::max(0.0f,std::min(1.0f,ftmp.z));
	}

    }
}

