/*
 * Copyright 1993-2009 NVIDIA Corporation.  All rights reserved.
 *
 * NVIDIA Corporation and its licensors retain all intellectual property and 
 * proprietary rights in and to this software and related documentation. 
 * Any use, reproduction, disclosure, or distribution of this software 
 * and related documentation without an express license agreement from
 * NVIDIA Corporation is strictly prohibited.
 *
 * Please refer to the applicable NVIDIA end user license agreement (EULA) 
 * associated with this source code for terms and conditions that govern 
 * your use of this NVIDIA software.
 * 
 */

/* Template project which demonstrates the basics on how to setup a project 
 * example application.
 * Device code.
 */

#ifndef _TEMPLATE_KERNEL_H_
#define _TEMPLATE_KERNEL_H_

#include <stdio.h>

#define IMAD(a, b, c) ( __mul24((a), (b)) + (c) )

__constant__ float4 f1[8];
__constant__ float4 f2[8];
__constant__ float4 f3[8];
__constant__ float4 f4[8];
__constant__ float4 fd[4];

////////////////////////////////////////////////////////////////////////////////
//! Simple test kernel for device functionality
//! @param g_idata  input data in global memory
//! @param g_odata  output data in global memory
////////////////////////////////////////////////////////////////////////////////
__global__ void
testKernel( float d, float* g_odata, int imageW, int imageH) 
{
 	const   int ix = IMAD(blockDim.x, blockIdx.x, threadIdx.x);
    	const   int iy = IMAD(blockDim.y, blockIdx.y, threadIdx.y);

	if ((ix<imageW) && (iy<imageH))
	{
		float b = (ix+0.5f)/imageW;
		float c = (iy+0.5f)/imageH;
		float a = 1.0f-b-c;

    		float4 ftmp;

		ftmp.z = a*fd[0].z+b*fd[1].z+c*fd[2].z+d*fd[3].z;
		ftmp.w = a*fd[0].w+b*fd[1].w+c*fd[2].w+d*fd[3].w;

		ftmp.z/=ftmp.w;

		g_odata[IMAD(iy, imageW, ix)] 	= max(0.0f,min(1.0f,ftmp.z));
	}
}

#endif // #ifndef _TEMPLATE_KERNEL_H_
